# HumanCron

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**at_time_hour** | **str** |  | [optional] 
**at_time_minute** | **str** |  | [optional] 
**days** | **list[str]** |  | [optional] 
**hours_period** | **str** |  | [optional] 
**scheduling_type** | **str** | the following fields are deprecated. do not use them. | [optional] 
**time_period** | **int** |  | [optional] 
**time_period_type** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


